"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.appUrl = exports.allowedOrigins = void 0;
const pulumi = require("@pulumi/pulumi");
const resources_js_1 = require("./resources.js");
const pulumiConfig = new pulumi.Config();
const edgePath = pulumiConfig.get('edgePath');
const staticPath = pulumiConfig.get('staticPath');
const prerenderedPath = pulumiConfig.get('prerenderedPath');
const FQDN = pulumiConfig.get('FQDN');
const serverHeadersStr = pulumiConfig.get('serverHeaders');
const serverArn = pulumiConfig.get('serverArn');
const optionsArn = pulumiConfig.get('optionsArn');
let serverHeaders = [];
if (serverHeadersStr) {
    serverHeaders = JSON.parse(serverHeadersStr);
}
const iamForLambda = (0, resources_js_1.getLambdaRole)([serverArn, optionsArn]);
const routerHandler = (0, resources_js_1.buildRouter)(iamForLambda, edgePath);
let certificateArn;
if (FQDN) {
    const [_, zoneName, ...MLDs] = FQDN.split('.');
    const domainName = [zoneName, ...MLDs].join('.');
    certificateArn = (0, resources_js_1.validateCertificate)(FQDN, domainName);
}
const bucket = (0, resources_js_1.buildStatic)(staticPath, prerenderedPath);
const distribution = (0, resources_js_1.buildCDN)(routerHandler, bucket, serverHeaders, FQDN, certificateArn);
if (FQDN) {
    (0, resources_js_1.createAliasRecord)(FQDN, distribution);
}
var getOrigins = [
    pulumi.interpolate `https://${distribution.domainName}`,
];
FQDN && getOrigins.push(`https://${FQDN}`);
(0, resources_js_1.buildInvalidator)(distribution, staticPath, prerenderedPath);
exports.allowedOrigins = getOrigins;
exports.appUrl = FQDN
    ? `https://${FQDN}`
    : pulumi.interpolate `https://${distribution.domainName}`;
//# sourceMappingURL=index.js.map